@@ -69,7 +69,8 @@ namespace libtorrent {
 	// this class provides a non-owning handle to a session and a subset of the
 	// interface of the session class. If the underlying session is destructed
 	// any handle to it will no longer be valid. is_valid() will return false and
-	// any operation on it will throw an invalid_session_handle.
+	// any operation on it will throw a system_error exception, with error code
+	// invalid_session_handle.
 	struct TORRENT_EXPORT session_handle
 	{
 		friend class session;
@@ -138,7 +139,7 @@ namespace libtorrent {
 		// which determines if a torrent should be included in the returned set
 		// or not. Returning true means it should be included and false means
 		// excluded. The ``flags`` argument is the same as to
-		// ``torrent_handle::status()``. Since ``pred`` is guaranteed to be
+		// torrent_handle::status(). Since ``pred`` is guaranteed to be
 		// called for every torrent, it may be used to count the number of
 		// torrents of different categories as well.
 		//
@@ -178,7 +179,7 @@ namespace libtorrent {
 		// Only torrents who has the state subscription flag set will be
 		// included. This flag is on by default. See add_torrent_params.
 		// the ``flags`` argument is the same as for torrent_handle::status().
-		// see torrent_handle::status_flags_t.
+		// see status_flags_t in torrent_handle.
 		void post_torrent_updates(status_flags_t flags = status_flags_t::all());
 
 		// This function will post a session_stats_alert object, containing a
@@ -468,6 +469,8 @@ namespace libtorrent {
 		// Both these functions are exposed for advanced custom use of the DHT.
 		// All torrents eligible to be announce to the DHT will be automatically,
 		// by libtorrent.
+		//
+		// For possible flags, see announce_flags_t.
 		void dht_get_peers(sha1_hash const& info_hash);
 		void dht_announce(sha1_hash const& info_hash, int port = 0, dht::announce_flags_t flags = {});
 
@@ -809,14 +812,6 @@ namespace libtorrent {
 		// shifting.
 		void remove_torrent(const torrent_handle& h, remove_flags_t options = {});
 
-#if TORRENT_ABI_VERSION == 1
-		// deprecated in libtorrent 1.1. use settings_pack instead
-		TORRENT_DEPRECATED
-		void set_pe_settings(pe_settings const& settings);
-		TORRENT_DEPRECATED
-		pe_settings get_pe_settings() const;
-#endif
-
 		// Applies the settings specified by the settings_pack ``s``. This is an
 		// asynchronous operation that will return immediately and actually apply
 		// the settings to the main thread of libtorrent some time later.
@@ -825,6 +820,22 @@ namespace libtorrent {
 		settings_pack get_settings() const;
 
 #if TORRENT_ABI_VERSION == 1
+
+#if defined __GNUC__
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
+#endif
+
+		// deprecated in libtorrent 1.1. use settings_pack instead
+		TORRENT_DEPRECATED
+		void set_pe_settings(pe_settings const& settings);
+		TORRENT_DEPRECATED
+		pe_settings get_pe_settings() const;
+
+#if defined __GNUC__
+#pragma GCC diagnostic pop
+#endif
+
 		// ``set_i2p_proxy`` sets the i2p_ proxy, and tries to open a persistent
 		// connection to it. The only used fields in the proxy settings structs
 		// are ``hostname`` and ``port``.
@@ -1048,13 +1059,14 @@ namespace libtorrent {
 #endif
 
 		// protocols used by add_port_mapping()
-		constexpr static portmap_protocol udp = portmap_protocol::udp;
-		constexpr static portmap_protocol tcp = portmap_protocol::tcp;
+		static constexpr portmap_protocol udp = portmap_protocol::udp;
+		static constexpr portmap_protocol tcp = portmap_protocol::tcp;
 
-		// add_port_mapping adds a port forwarding on UPnP and/or NAT-PMP,
-		// whichever is enabled. The return value is a handle referring to the
-		// port mapping that was just created. Pass it to delete_port_mapping()
-		// to remove it.
+		// add_port_mapping adds one or more port forwards on UPnP and/or NAT-PMP,
+		// whichever is enabled. A mapping is created for each listen socket
+		// in the session. The return values are all handles referring to the
+		// port mappings that were just created. Pass them to delete_port_mapping()
+		// to remove them.
 		std::vector<port_mapping_t> add_port_mapping(portmap_protocol t, int external_port, int local_port);
 		void delete_port_mapping(port_mapping_t handle);
 
